@@ -72,11 +72,19 @@ where
 }
 
 /// Run a `cargo build` command.
-pub fn build(mode: Mode) -> Result<()> {
+pub fn build(mode: Mode, bins: &[String], target: Option<&str>) -> Result<()> {
     let mut cmd = Cargo::new("build");
     if let Mode::Release = mode {
         cmd.arg("--release");
     }
+    for bin in bins {
+        cmd.arg("--bin");
+        cmd.arg(bin);
+    }
+    if let Some(target) = target {
+        cmd.arg("--target");
+        cmd.arg(target);
+    }
     cmd.run()
 }
 
@@ -121,6 +129,6 @@ pub fn read_manifest(dir: &Path) -> Result<toml::Document> {
 /// Write a Cargo manifest.
 pub fn write_manifest(dir: &Path, doc: &toml::Document) -> Result<()> {
     let path = dir.join("Cargo.toml");
-    fs::write(&path, &doc.to_string_in_original_order())?;
+    fs::write(&path, &doc.to_string())?;
     Ok(())
 }
