@@ -73,20 +73,29 @@ fn init(manifest_dir: &Path, name: Option<OsString>) -> Result<()> {
 }
 
 /// Build the workflow.
-fn build(release: bool) -> Result<()> {
+fn build(bins: Vec<String>, release: bool, target: Option<String>) -> Result<()> {
     let mode = if release {
         cargo::Mode::Release
     } else {
         cargo::Mode::Debug
     };
-    cargo::build(mode)?;
+    cargo::build(mode, &bins, target.as_deref())?;
 
     let metadata = cargo::metadata()?;
     let workflow_dir = metadata.workspace_dir.join("workflow");
     fs::create_dir_all(&workflow_dir)?;
 
+    let src_dir = match target {
+        Some(target) => metadata.target_dir.join(target).join(mode.dir()),
+        None => metadata.target_dir.join(mode.dir()),
+    };
+
     for binary_name in &metadata.binary_names {
-        let src = metadata.target_dir.join(mode.dir()).join(binary_name);
+        if !bins.is_empty() && !bins.contains(binary_name) {
+            continue;
+        }
+
+        let src = src_dir.join(binary_name);
         let dst = workflow_dir.join(binary_name);
         fs::copy(&src, &dst)?;
         print(
@@ -173,24 +182,49 @@ enum Command {
     /// Create a new Rust alfred workflow.
     New {
         path: PathBuf,
+
+        /// Set the resulting package name, defaults to the directory name.
         #[clap(long)]
         name: Option<OsString>,
     },
+
     /// Create a new Rust alfred workflow in an existing directory [default: .]
     Init {
         path: Option<PathBuf>,
+
+        /// Set the resulting package name, defaults to the directory name.
         #[clap(long)]
         name: Option<OsString>,
     },
+
     /// Build the workflow.
     Build {
+        /// Build only the specified binary.
+        #[clap(long, value_name = "NAME")]
+        bin: Vec<String>,
+
+        /// Build artifacts in release mode, with optimizations.
         #[clap(long)]
         release: bool,
+
+        /// Build for the target triple.
+        #[clap(long, value_name = "TRIPLE")]
+        target: Option<String>,
     },
+
     /// Symlink the workflow directory to the Alfred workflow directory.
     Link,
+
     /// Package the workflow as an `.alfredworkflow` file.
-    Package,
+    Package {
+        /// Package only the specified binary.
+        #[clap(long, value_name = "NAME")]
+        bin: Vec<String>,
+
+        /// Build for the target triple.
+        #[clap(long, value_name = "TRIPLE")]
+        target: Option<String>,
+    },
 }
 
 #[derive(Debug, Parser)]
@@ -219,14 +253,18 @@ fn main() -> anyhow::Result<()> {
             let path = path.as_deref().unwrap_or_else(|| Path::new("."));
             init(path, name)?;
         }
-        Command::Build { release } => {
-            build(release)?;
+        Command::Build {
+            bin,
+            release,
+            target,
+        } => {
+            build(bin, release, target)?;
         }
         Command::Link => {
             link()?;
         }
-        Command::Package => {
-            build(true)?;
+        Command::Package { bin, target } => {
+            build(bin, true, target)?;
             package()?;
         }
     }
